create table TEST_ADAPTER (
	TEST_ID int not null,
	TEST_STRING varchar(64),
	TEST_NUMBER int,
	TEST_DATE date,
	TEST_TIME time,
	TEST_TIMESTAMP timestamp,
	primary key (TEST_ID)
);
